#' Plot the results of wmdsGN
#'
#'
#' @param wmds Th result of wmdsGN
#' @param type The type of plot \cr
#' = 1 to plot stimulus and subject configuration \cr
#' = 2 to plot the optimal transformation \cr
#' = 3 to plot the linear fit
#' @param ... grarical paramter: xmim, title, etc
#'
#' @export
#'

plot_wmds <- function( wmds, type=1:2, ... ){
 # plot wmdsgn result
 # Shin-ichi Mayekawa
 # 20151127
 # bugfix: 20160630
 #

 if( 1 %in% type ){
  # stimulus and subject config
  X=wmds$X; W=wmds$W
  ndim=ncol(X)
  sn=rownames(X); sbjn=rownames(W)
  if( is.null(sn) ) sn=paste("S",1:nrow(X),sep="")
  if( is.null(sbjn) ) sbjn=paste("sbj",1:nrow(W),sep="")
  for( i in 2:ndim ){
   for( j in 1:(i-1) ){
    xl=paste("X",j,sep=""); yl=paste("X",i,sep="")
    plot( X[,j], X[,i], sub="Common Stimulus Configuration"
          , xlab=xl, ylab=yl, pch = 21, cex=1.2, ... )
    text( X[,j], X[,i], sn, pos=4 )
    xl=paste("W",j,sep=""); yl=paste("W",i,sep="")
    maxw=max(W)*1.05
    plot( W[,j], W[,i], sub="Subject weight", pch = 21, cex=1.2
          , xlab=xl, ylab=yl, xlim=c(0,maxw), ylim=c(0,maxw) )
    text( W[,j], W[,i], sbjn, pos=4 )
   }
  }
 }

 if( 2 %in% type ){
  # transformation
  vO=wmds$vO; vDhat=wmds$vDhat
  nG=ncol(vO)
  sbjn=rownames(W); if( is.null(sbjn) ) sbjn=paste("sbj",1:nG,sep="")
  for( k in 1:nG ){
   o=vO[,k]; dh=vDhat[,k]
   od=order(o)
   o=o[od]; dh=dh[od]
   xl=paste("O",k,sep=""); yl=paste("Dhat",k,sep="")
   sb=paste("optimal transformation with mlevel = ", wmds$mlevel
            ," and ndim = ", ndim, sep="")
   plot( o, dh, type="l", sub=sb, xlab=xl, ylab=yl)
  }
 }

 if( 3 %in% type ){
  # linear fit
  vDhat=wmds$vDhat; vD=wmds$vD
  nG=ncol(vDhat)
  sbjn=rownames(W); if( is.null(sbjn) ) sbjn=paste("sbj",1:nG,sep="")
  for( k in 1:nG ){
   dh=vDhat[,k]; d=vD[,k]
   od=order(dh)
   d=d[od]; dh=dh[od]
   xl=paste("Dhat",k,sep=""); yl=paste("D",k,sep="")
   sb=paste("linear fit with mlevel = ", wmds$mlevel
            ," and ndim = ", ndim, sep="")
   plot( dh, d, type="p", sub=sb, xlab=xl, ylab=yl)
  }
 }


} # end of plot_wmds
