% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/indscaletc.R
\name{smscl}
\alias{smscl}
\title{Simultaneous Diagonalization of Several Symmetric Matrices}
\usage{
smscl(C, lmax = 100, eps = 1e-08, print = 2)
}
\arguments{
\item{C}{Input array of symmetric matrices}

\item{lmax}{max # of iterations}

\item{eps}{convergence criterion}

\item{print}{= 1 to print result}
}
\value{
A list of \cr
T, W, rmse, llll=iteretions needed, converged=1 if converged.
}
\description{
Simultaneous Diagonalization of Several Symmetric Matrices
}
\details{
Given matrices \eqn{C_k, n=1,2,...,nG}, find the orthonormal matrix T
 such that
\deqn{
     T' C_k T == W_k,    k=1,2,...,nG, diag
     }
   OR
\deqn{
     C_k == T W_k T',    k=1,2,...,nG
     }
 \cr
 This program minimizes
\deqn{
   rss2 = sum_k (  (C_k - T W_k T')^2 )
   }
 with respect to orthogonal T and diagonal W_k. \cr
}
\examples{
set.seed(1701)
W <- matrix( c( 1,1, 2,1, 1,2 ),,2, byrow=1 )
rownames(W) <- paste("sbj",1:nrow(W),sep="")
colnames(W) <- paste("d",1:ncol(W),sep="")
theta <- pi/3
T <- matrix(c(cos(theta),sin(theta),-sin(theta),cos(theta)),2,2)
C <- array(0,dim=c(2,2,3))
for( k in 1:nrow(W) ){
 C[,,k] <- T\%*\%diag(W[k,])\%*\%t(T)
 E <- 0.05*matrix(rnorm(4),2,2);    E <- (E+t(E))/2
 C[,,k] <- C[,,k] + E
}
dimnames(C) <- list(colnames(W),colnames(W),rownames(W))

res <- smscl( C, lmax=100, eps=1e-8, print=2 )
}
\references{
De Leeuw, Jan, and  Pruzansky, Sandra (1978)
A New Computational Method to Fit the Weighted Euclidean Distance Model.
Psychometrika, v43 n4 p479-9
}

