% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/wmdsGN.R
\name{wmdsGN}
\alias{wmdsGN}
\title{Individual Differences Multidimensional Scaling
by the Gauss-Newton Method}
\usage{
wmdsGN(O, ndim, init = 1, mlevel = 5, nknots = 5, estX = 1, estW = 1,
  X = NULL, W = NULL, SQUAREM = 3, nSQUAREM = 3, minalpha = -9999,
  maxalpha = -1, always = 1, reset1 = 0, reset2 = 1, maxiter = 100,
  eps = 1e-06, epsd = 1e-06, print = 2, debug = 0)
}
\arguments{
\item{O}{n x n x nG array of observed dissimilarity matrices}

\item{ndim}{# of dimensions}

\item{init}{= 0 to use random initial for X matrix}

\item{mlevel}{= 1|2|3|4|5|6|9 \cr
  1="continuous nominal", 2="discrete nominal"
, 3="continuous ordinal(primary)", 4="discrete ordinal(secondary)"
, 5="interval", 6="monotone spline", 9="no transformation at all"}

\item{nknots}{# of knots for monotone spline transformation}

\item{estX}{= 0 to skip the estimation of X}

\item{estW}{= 0 to skip the estimation of W}

\item{X}{The initial value of X when estX=0}

\item{W}{The initial value of W when estW=0}

\item{SQUAREM}{= 3 :   See the help of iSQUAREM in lazy.accel package.}

\item{nSQUAREM}{>= 1 # of iterations a which SQUAREM begins.}

\item{minalpha}{= -999 :   See the help of iSQUAREM in lazy.accel package.}

\item{maxalpha}{= -1 :   See the help of iSQUAREM in lazy.accel package.}

\item{always}{= 1 :   See the help of iSQUAREM in lazy.accel package.}

\item{reset1}{= 0 :   See the help of iSQUAREM in lazy.accel package.}

\item{reset2}{= 1 :   See the help of iSQUAREM in lazy.accel package.}

\item{maxiter}{The maximum # of iterations}

\item{eps}{The convergence criterion for the relative improvement of rmse.}

\item{epsd}{The convergence criterion for the difference of param values.}

\item{print}{= 1 to print the result}

\item{debug}{= 1 to print the intermediate results}
}
\value{
A list of the following: \cr
 rmse The rmse minimized \cr
 stress1 stress1 \cr
 stress2 stress2 minimized \cr
 stress1_s stress1 for each individual \cr
 stress2_s stress2 for each individual \cr
 X n x ndim group configuration matrix \cr
 W nG x ndim subject weight matrix \cr
 vO The roll-out of the observed dissimilarity matrices.\cr
 vDhat The roll-out of the optimal transformation matrices.\cr
 vD The roll-out of the distance matrices.\cr
 iter_hist The history of the iteration with the columns: \cr
  llll, rmse, maxadX, maxadW. \cr
 mlevel, nknots, ndim
}
\description{
Individual Differences Multidimensional Scaling
by the Gauss-Newton Method
}
\details{
The puropose of this function is to demonstrate how
the ALS (Alternating Least Squares), the Gauss-Newton method,
and inline SQUAREM can be utilized in MDS context. \cr
The program may not be very efficient but it reduces rmse (stress2) at each
phase of iteration. \cr
\cr
The basic algorithm is as follows: \cr
0) find initial value of X and W.\cr
1) minimize rmse w.r.t. X given W by the GN method. \cr
2) minimize rmse w.r.t. W given X by the GN method. \cr
3) for every three iterations,
update X and W with inline SQUAREM if requested. \cr
4) minimize rmse w.r.t. optimal transformation of O. \cr
5) check convergence. \cr
6) go back to step 1) if not converged. \cr
\cr\cr

  This program minimizes the stress formula 2 in terms of the distance:
 \deqn{
 \sum_k \sum_{i>j} ( dh_{ijk} - d_{ijk} )^2 / variance( dh_{,,k} )
 }
   with respect to  X, W  and dh. \cr
\cr
  Actual minimization is done by minimizing
  \deqn{
      \sum_k \sum_{i>j} ( dh_{ijk} - d_{ijk} )^2
      }
 with respec to  X, W  and dh and normalizing each dh[,,k] so that its \cr
 mean is equal to the mean of d[,,k] and its varaiance is equal to unity.\cr
\cr
  Given X and W, the optimal dh[,,k] is found by regressing d[,,k] on o[,,k]
  under the suitable assumption specified by mlevel. \cr
\cr
  Given dh and W, X is updated using the Gauss-Newton method. \cr
  Given dh and X, W is updated using the Gauss-Newton method. \cr
\cr
\cr
  When nG >= 2, \cr
  X is normalized so that 1'X = 0' and diag(X'X) = n I. \cr

  When nG = 1, W is set equal to 1 and 1'X = 0' will be enforced. \cr

  When mlevel = 9, dh is set equal to o and will not be normalized.


\cr\cr\cr
For the monotone least squares transformation, see the description of
lazy.stat::mlsreg. \cr
For the monotone spline, see the description of lazy.stat::spreg
with type="m" option.

 \cr
 \cr
 Note on the iSQUAREM: \cr
 Try always=1 with maxalpha=-1 first. \cr
 If it seems not working, use always=0 with maxalpha=1. \cr
 Changing reset1=1 and reset2=2 may help. \cr
 If all of the above fail, be patient and use SQUAREM=0.
 \cr\cr
}
\examples{
# generate data
set.seed(1701)
n=10; nG=3; ndim=2
npair=n*(n-1)/2
X=matrix(rnorm(n*ndim), n, ndim)
W=matrix(runif(nG*ndim), nG, ndim)
W=W\%*\%Diag(1/sqrt(colSums(W^2)))

# weighted Euclidean distance
vD=vech(distancew( X, W ),nodiag=1)

# add scaled error
stdD=sqrt( diag(cov(vD)*(npair-1)/npair) )
stderr=.2
vO=vD + matrix(rnorm(npair*nG),npair,nG )\%*\%Diag(stderr*stdD)
vO[vO<0]=0

# nonlinear transformation for subj1 and 2
# obs1=d^(1/3)  and  obs2=d-3
vO[,1]=vO[,1]^(1/3)
vO[,2]=vO[,2]^3

# back to square array
O=vechinv(vO, nodiag=1, array=1) # this is n x n x nG

# Fit the Weighted Model with monotone spline transformations
res1=wmdsGN( O, ndim=2, mlevel=6, print=2 )

# dhat1=obs1^3,  dhat2=obs2^(1/3)
plot_wmds( res1 )
# res1=wmdsGN( O, ndim=2 , print=2, SQUAREM=0 )
}

